@@ -1,5 +1,5 @@
-from aws_utils.ssm import SSM
-from aws_utils.kms import KMS
+from .aws_utils.ssm import SSM
+from .aws_utils.kms import KMS
 import argparse
 import json
 
